==> flutter_firebase_basic_tools-0.0.20.tar.gz: lib/widgets/language_picker.dart <==
import 'dart:convert';
import 'package:flutter_firebase_basic_tools/logic/custom_colors.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart';
import 'package:shared_preferences/shared_preferences.dart';

class LanguagePicker extends StatefulWidget {
  const LanguagePicker({
    @required this.currentLanguage,
    @required this.parentWidget,
    this.function,
    @required this.itemsTextColor,
    @required this.apiKey,
  });

  final String currentLanguage;
  final parentWidget;
  final Function function;
  final Color itemsTextColor;
  final String apiKey;

  @override
  _LanguagePickerState createState() => _LanguagePickerState();
}

class _LanguagePickerState extends State<LanguagePicker> {
  String languageValue = 'English';
  List<String> languageValues = [
    'English',
  ];

  String target = "";
  List languagesList;

  CustomColors customColors = CustomColors();

  SharedPreferences prefs;

  initSharedPreferences(String apiKey) async {
    prefs = await SharedPreferences.getInstance();

    if (prefs.getString("language_target") != null) {
      target = prefs.getString("language_target");
    } else {
      target = "en";
      prefs.setString("language_target", target);
    }

    widget.parentWidget.currentLanguage = target;

    getLanguagesList(apiKey);
  }

  getLanguagesList(String apiKey) async {
    String url =
        "https://translation.googleapis.com/language/translate/v2/languages?key=$apiKey&target=en";

    Response response = await get(url);
    Map<String, dynamic> body = jsonDecode(response.body);

    languagesList = body['data']['languages'];

    languageValues.clear();

    languagesList.forEach((n) => languageValues.add(n['name']));

    languageValue = (languagesList
        .firstWhere((language) => language["language"] == target))["name"];

    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences(widget.apiKey);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: DropdownButton<String>(
        isExpanded: true,
        value: languageValue,
        iconSize: 24,
        elevation: 16,
        iconEnabledColor: Colors.white,
        iconDisabledColor: Colors.yellow,
        underline: Container(
          height: 2,
          color: Colors.white,
        ),
        onChanged: (String newValue) {
          setState(() {
            languageValue = newValue;

            var selectedLanguage = languagesList
                .singleWhere((language) => language['name'] == languageValue);

            prefs.setString('language_target', selectedLanguage['language']);

            widget.parentWidget.currentLanguage = selectedLanguage['language'];

            if (widget.function != null) {
              widget.function();
            }

            widget.parentWidget.translationStream.translate();

            widget.parentWidget.setState(() {});
          });
        },
        selectedItemBuilder: (BuildContext context) {
          return languageValues.map<DropdownMenuItem<String>>((String value) {
            return DropdownMenuItem<String>(
              value: value,
              child: Text(
                value,
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 16,
                ),
              ),
            );
          }).toList();
        },
        items: languageValues.map<DropdownMenuItem<String>>((String value) {
          return DropdownMenuItem<String>(
            value: value,
            child: Text(
              value,
              style: TextStyle(
                color: widget.itemsTextColor,
                fontSize: 16,
              ),
            ),
          );
        }).toList(),
      ),
    );
  }
}

==> flutter_firebase_basic_tools-0.0.25.tar.gz: lib/widgets/language_picker.dart <==
import 'dart:convert';
import 'package:flutter_firebase_basic_tools/logic/custom_colors.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart';
import 'package:shared_preferences/shared_preferences.dart';

class LanguagePicker extends StatefulWidget {
  const LanguagePicker({
    @required this.currentLanguage,
    @required this.parentWidget,
    this.function,
    @required this.itemsTextColor,
    @required this.apiKey,
  });

  final String currentLanguage;
  final parentWidget;
  final Function function;
  final Color itemsTextColor;
  final String apiKey;

  @override
  _LanguagePickerState createState() => _LanguagePickerState();
}

class _LanguagePickerState extends State<LanguagePicker> {
  String languageValue = 'English';
  List<String> languageValues = [
    'English',
  ];

  String target = "";
  List languagesList;

  CustomColors customColors = CustomColors();

  SharedPreferences prefs;

  initSharedPreferences(String apiKey) async {
    prefs = await SharedPreferences.getInstance();

    if (prefs.getString("language_target") != null) {
      target = prefs.getString("language_target");
    } else {
      target = "en";
      prefs.setString("language_target", target);
    }

    widget.parentWidget.currentLanguage = target;

    getLanguagesList(apiKey);
  }

  getLanguagesList(String apiKey) async {
    String url =
        "https://translation.googleapis.com/language/translate/v2/languages?key=$apiKey&target=en";

    Response response = await get(url);
    Map<String, dynamic> body = jsonDecode(response.body);

    languagesList = body['data']['languages'];

    languageValues.clear();

    languagesList.forEach((n) => languageValues.add(n['name']));

    languageValue = (languagesList
        .firstWhere((language) => language["language"] == target))["name"];

    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences(widget.apiKey);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: DropdownButton<String>(
        isExpanded: true,
        value: languageValue,
        iconSize: 24,
        elevation: 16,
        iconEnabledColor: Colors.white,
        iconDisabledColor: Colors.yellow,
        underline: Container(
          height: 2,
          color: Colors.white,
        ),
        onChanged: (String newValue) {
          setState(() {
            languageValue = newValue;

            var selectedLanguage = languagesList
                .singleWhere((language) => language['name'] == languageValue);

            prefs.setString('language_target', selectedLanguage['language']);

            widget.parentWidget.currentLanguage = selectedLanguage['language'];

            if (widget.function != null) {
              widget.function();
            }

            widget.parentWidget.translationStream.translate(widget.apiKey);

            widget.parentWidget.setState(() {});
          });
        },
        selectedItemBuilder: (BuildContext context) {
          return languageValues.map<DropdownMenuItem<String>>((String value) {
            return DropdownMenuItem<String>(
              value: value,
              child: Text(
                value,
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 16,
                ),
              ),
            );
          }).toList();
        },
        items: languageValues.map<DropdownMenuItem<String>>((String value) {
          return DropdownMenuItem<String>(
            value: value,
            child: Text(
              value,
              style: TextStyle(
                color: widget.itemsTextColor,
                fontSize: 16,
              ),
            ),
          );
        }).toList(),
      ),
    );
  }
}
